============
Installation
============

.. include:: ../README.rst
   :start-after: installation-begin
   :end-before: installation-end

To access the Scopus database you will need API keys which you register at http://dev.elsevier.com/myapikey.html.  If your institution subscribes to Scopus, you may need to be in your institution's network or you need to have an InstToken, which can also be saved in the configuration.  Non-subscribers only get limited access to two APIs.  See https://dev.elsevier.com/api_key_settings.html for details.
On first usage, `pybliometrics` prompts you for authentication details (API keys and, if necessary, InstToken) and stores them in `~/.config/pybliometrics.cfg` (see :doc:`Configuration </configuration>`).
